#  All functions are used for regression problems
 funcRegPred <- c("glm", "glmStepAIC","gam","rpart","rpart2","ctree","ctree2","evtree","obliqueTree",
"gbm", "blackboost","bstTree","glmboost","gamboost","bstLs","bstSm","rf","parRF","cforest","Boruta","RRFglobal","RRF",
"treebag","bag","logicBag","bagEarth","nodeHarvest","partDSA","earth","gcvEarth","logreg","glmnet", "nnet","mlp","mlpWeightDecay",
"pcaNNet", "avNNet","rbf","pls","kernelpls","simpls","widekernelpls","spls", "svmLinear", "svmRadial", "svmRadialCost", "svmPoly",
"gaussprLinear", "gaussprRadial", "gaussprPoly", "knn", "xyf", "bdk","lm", "lmStepAIC","leapForward", "leapBackward","leapSeq",
"pcr", "icr", "rlm", "neuralnet", "qrf","qrnn","M5Rules","M5","cubist", "ppr","penalized","ridge","lars","lars2","enet","lasso",
 "relaxo","foba","krlsRadial","krlsPoly","rvmLinear","rvmRadial","rvmPoly","superpc")